Latch.Error (latch v0.5.0)

Errors returned by the public Latch and Latch.Client API.

Every public function that can fail returns {:error, Latch.Error.t()}. Each error is an exception struct so callers can eitehr pattern match on its fields or raise/1 it directly.

Summary

Types